==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1ManagedFieldsEntryFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1ManagedFieldsEntryFluent<A extends V1ManagedFieldsEntryFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public Object getFields();
    public A withFields(Object fields);
    public Boolean hasFields();
    public String getManager();
    public A withManager(String manager);
    public Boolean hasManager();
    public A withNewManager(String arg1);
    public A withNewManager(StringBuilder arg1);
    public A withNewManager(StringBuffer arg1);
    public String getOperation();
    public A withOperation(String operation);
    public Boolean hasOperation();
    public A withNewOperation(String arg1);
    public A withNewOperation(StringBuilder arg1);
    public A withNewOperation(StringBuffer arg1);
    public DateTime getTime();
    public A withTime(DateTime time);
    public Boolean hasTime();
    public A withNewTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewTime(Object arg0);
    public A withNewTime(long arg0);



}

==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1ManagedFieldsEntryFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1ManagedFieldsEntryFluent<A extends V1ManagedFieldsEntryFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getFieldsType();
    public A withFieldsType(String fieldsType);
    public Boolean hasFieldsType();
    public A withNewFieldsType(String arg1);
    public A withNewFieldsType(StringBuilder arg1);
    public A withNewFieldsType(StringBuffer arg1);
    public Object getFieldsV1();
    public A withFieldsV1(Object fieldsV1);
    public Boolean hasFieldsV1();
    public String getManager();
    public A withManager(String manager);
    public Boolean hasManager();
    public A withNewManager(String arg1);
    public A withNewManager(StringBuilder arg1);
    public A withNewManager(StringBuffer arg1);
    public String getOperation();
    public A withOperation(String operation);
    public Boolean hasOperation();
    public A withNewOperation(String arg1);
    public A withNewOperation(StringBuilder arg1);
    public A withNewOperation(StringBuffer arg1);
    public DateTime getTime();
    public A withTime(DateTime time);
    public Boolean hasTime();
    public A withNewTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewTime(Object arg0);
    public A withNewTime(long arg0);



}
